<?php 

class Traitement extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("ResultatExamenModel","rexamen");

		$this->load->model("NoteExamenModel","nexamen");
		$this->load->model("NoteExamenOnlineModel","nonline");

		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");

		$this->load->model("BaremeModel","bareme");
		$this->load->model("PassingMarkModel","pass");
	}

	public function index($values=null)
	{
		$data["active"] = 3;
		$data["lists"] = $this->rexamen->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$classes = $this->classe->getAll();
		$niveaux = [];

		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("examen/traitement",$data);
	}

	public function resetForm($values)
	{
		$data["active"] = 3;
		$data["lists"] = [];

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		if(isset($values["exercice"]))
		{
			$data["terms"] = $this->term->getAllByExercice((int)$values["exercice"]);
		}

		$classes = $this->classe->getAll();
		$niveaux = [];

		if(isset($values["classe"]))
		{
			$niveaux = $this->niveau->getByClasse((int)$values["classe"]);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;


		$data["values"] = $values;

		$this->load->view("examen/traitement",$data);
	}


	public function run()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm($_POST);
			return false;
		}

		$type = trim($_POST['type']);

		if($type === "Salle")
		{
			$this->runSalle();
		}
		else if($type === "Online")
		{
			$this->runOnline();
		}
	}

	private function runSalle()
	{
		$niveau = (int)$_POST['niveau'];
		$term = (int)$_POST['term'];

		$etudiants = $this->nexamen->getMatriculesEtudiant($niveau,$term);

		if(empty($etudiants))
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Aucune donnée à traiter")));
			return false;
		}

		$baremes = $this->bareme->getByNiveau($niveau);
		if(empty($baremes))
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Barème incomplet pour ce niveau")));
			return false;
		}

		$passMark = $this->pass->getByNiveau($niveau);
		if(!$passMark)
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Passmark non defini pour ce niveau")));
			return false;
		}
		$passMark = (float)$passMark->scorePassingMark;

		$state = null; //Status resultat
		$totalBareme = $this->bareme->getTotalByNiveau($niveau);

		$target = ($totalBareme * $passMark) / 100; // score à atteindre pour passer

		foreach($etudiants as $etu)
		{
			$readyTo = $niveau; // Niveau supérieur du niveau actuelle
			$notes = $this->nexamen->getNotes($niveau,$term,$etu->matriculeEtudiant);

			if(count($baremes) !== count($notes))
			{
				$this->resetForm(array_merge($_POST,Utility::getAlert("error","Traitement non effectué! Résultat incomplet")));
				return false;
			}
			
			$totalNote = 0;
			$dropout = false;

			foreach($notes as $nt)
			{
				if($nt->note === null)
				{
					$dropout = true;
				}
				$totalNote += (float)$nt->note;
			}
			
			if($dropout)
			{
				$state = "DROPOUT";
			}
			else
			{
				if($totalNote >= $target)
				{
					$state = "PASS";
					$readyTo = $this->niveau->getNextLevel($niveau);
				}
				else
				{
					$state = "REPEATER";
				}
			}

			$res = $this->rexamen->getByTermAndMatricule($term,$etu->matriculeEtudiant); 
			if(!$res)
			{
				$this->rexamen->create(["matriculeEtudiant","idTerm","totalNote","idNiveau","readyTo","state"],[$etu->matriculeEtudiant,$term,$totalNote,$niveau,$readyTo,$state]);	
			}
			else
			{
				$this->rexamen->update(["totalNote","readyTo","state"],[$totalNote,$readyTo,$state,$res->idResultatExamen]);
			}
			

		}

		$this->index(Utility::getAlert("success","Traitement effectué"));
	}

	private function runOnline()
	{
		$niveau = (int)$_POST['niveau'];
		$term = (int)$_POST['term'];

		$etudiants = $this->nonline->getMatriculesEtudiant($niveau,$term);

		if(empty($etudiants))
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Aucune donnée à traiter")));
			return false;
		}

		$passMark = $this->pass->getByNiveau($niveau);
		if(!$passMark)
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Passmark non defini pour ce niveau")));
			return false;
		}
		$passMark = (float)$passMark->scorePassingMark;

		$state = null; //Status resultat
		$readyTo = $niveau; // Niveau supérieur du niveau actuelle

		foreach($etudiants as $etu)
		{
			$nt = $this->nonline->getNotes($niveau,$term,$etu->matriculeEtudiant);
			
			$totalNote = 0;
			$dropout = false;

			if($nt->note95 === null || $nt->note5 === null)
			{
				$dropout = true;
			}
			$moyenne = ((float)$nt->note95 * 100) / 95;
			$totalNote = $moyenne + (float)$nt->note5; 
			
			if($dropout)
			{
				$state = "DROPOUT";
			}
			else
			{
				if($totalNote >= $passMark)
				{
					$state = "PASS";
					$readyTo = $this->niveau->getNextLevel($niveau);
				}
				else
				{
					$state = "REPEATER";
				}
			}

			$res = $this->rexamen->getByTermAndMatricule($term,$etu->matriculeEtudiant); 
			if(!$res)
			{
				$this->rexamen->create(["matriculeEtudiant","idTerm","totalNote","idNiveau","readyTo","state"],[$etu->matriculeEtudiant,$term,$totalNote,$niveau,$readyTo,$state]);	
			}
			else
			{
				$this->rexamen->update(["totalNote","readyTo","state"],[$totalNote,$readyTo,$state,$res->idResultatExamen]);
			}
			

		}

		$this->index(Utility::getAlert("success","Traitement effectué"));
	}

	public function getDetail()
	{
		$id = (int)$_POST["id"];
		$res = $this->rexamen->getOne($id);
		$notes = [];

		$niveau = $res->idNiveau;
		$term = $res->idTerm;
		$matricule = $res->matriculeEtudiant;

		if($res->joursCours === "Online")
		{
			$notes = $this->nonline->getNotes($niveau,$term,$matricule);
		}
		else
		{
			$notes = $this->nexamen->getNotes($niveau,$term,$matricule);
		}

		$data["resultat"] = $res;
		$data["notes"] = $notes;

		//dump($data["resultat"]);die;

		$this->load->view("examen/components/modal_detail_resultat",$data);
	}

	public function delete()
	{
		$id = (int)$_POST['id'];
		$this->rexamen->delete($id);
		$this->index(Utility::getAlert("success","Resultat examen supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}
		$data["active"] = 3;
		$data["lists"] = $this->rexamen->getAllSearch("%".$query."%");

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$classes = $this->classe->getAll();
		$niveaux = [];

		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$data["query"] = $query;

		$this->load->view("examen/traitement",$data);
	}

	public function export()
	{
		$all = $this->rexamen->getAll();
		$data = [];

		foreach ($all as $value) {

			$data[] = (object)[
				"Session" => $value->anneeExercice . " - " . $value->nomTerm,
				"Matricule" => $value->matriculeEtudiant,
				"Nom & prénoms" => $value->nom . " " . $value->prenom,
				"Classe" => $value->codeClasse,
				"Niveau" => $value->codeNiveau,
				"Ready to" => $value->readyToCodeNiveau,
				"Status" => $value->state
			];
		}
		ExportExcel::exporter('resultatExamen', $data);
	}



}