<?php 

class Company extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("CompanyModel","company");

		$this->load->model("InscriptionCoursModel","inscription");
		$this->load->model("PrioriteModel","priorite");
	}

	public function index($values=null)
	{
		$data["active"] = 2;
		$data["lists"] = $this->inscription->getAllWithCompany();

		$exercices = $this->exercice->getAll();
		$terms = [];
		if(count($exercices))
		{
			$terms = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$data["exercices"] = $exercices;
		$data["terms"] = $terms;

		$data["compagnies"] = $this->company->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("inscription/company",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("compagnie","compagnie","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm($_POST);
			return false;
		}
		$term = (int)$_POST['term'];
		$compagnie = (int)$_POST['compagnie'];

		$etudiants = $this->inscription->getEtudiantsCompany($term,$compagnie);

		if(empty($etudiants))
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","Ce compagnie n\'a pas des etudiants à cette sesion")));
			return false;
		}

		$etudiantsWithPriorite = [];
		foreach($etudiants as $etu)
		{
			if((int)$etu->ordrePriorite)
			{
				$etudiantsWithPriorite[] = $etu;
			}
			$this->inscription->update(["isValid"],[1,$etu->idInscriptionCours]);
		}

		if(count($etudiantsWithPriorite))
		{
			$montant = $this->priorite->getMontant(count($etudiantsWithPriorite));

			foreach($etudiantsWithPriorite as $etu)
			{
				$this->inscription->update(["priorite"],[$montant,$etu->idInscriptionCours]);
			}
		}

		$this->index(Utility::getAlert("success"));
	}

	public function print()
	{
        $company = (int) $_POST['compagnie'];
        $term = (int) $_POST['term'];

        $inscrits = $this->inscription->getEtudiantsCompany($term,$company);

        if (!$inscrits) 
        {
            exit();
        }

        foreach ($inscrits as $inscrit) 
        {
            $data['recus'][] = $this->inscription->getRecu($inscrit->idInscriptionCours);
        }

        $this->load->view('inscription/components/factureCompany', $data);
	}

	private function resetForm($values)
	{
		$data["active"] = 2;
		$data["lists"] = $this->inscription->getAllWithCompany();

		$data["action"] = "create";

		$exercices = $this->exercice->getAll();
		$terms = [];
		if(isset($_POST["exercice"]))
		{
			$terms = $this->term->getAllByExercice((int)$_POST['exercice']);
		}

		$data["exercices"] = $exercices;
		$data["terms"] = $terms;

		$data["compagnies"] = $this->company->getAll();


		$data["values"] = $values;

		$this->load->view("inscription/company",$data);
	}

	public function export()
	{
		$all = $this->inscription->getAllWithCompany();
		$data = [];

		foreach ($all as $value) {
			$data[] = (object)[
				"Session" => $value->anneeExercice . " - " . $value->nomTerm,
				"Nombre etudiant" => $value->count,
				"Companie" => $value->nomCompany,
				"Contact" => $value->contactCompany
			];
		}
		ExportExcel::exporter('inscription_company', $data);
	}

}