<?php 

class Mutation extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("MutationModel","mutation");

		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("HoraireCoursModel","horaire");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
		$this->load->model("RepartitionCoursModel","repartition");
		$this->load->model("InscriptionCoursModel","inscription");
	}

	public function index($values=null)
	{
		$data["active"] = 1;

		$data["lists"] = $this->mutation->getAll();

		$exercices = $this->exercice->getAll();
		$terms = [];
		$idTerm = 0;

		if($exercices)
		{
			$terms = $this->term->getAllByExercice($exercices[0]->idExercice); 
		}
		if(count($terms))
		{
			$idTerm = (int)$terms[0]->idTerm;
		}

		$data["exercices"] = $exercices;
		$data["terms"] = $terms;

		$classes = $this->classe->getAll();
		$niveaux = [];
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idSalle = 0;
		$idHoraire = 0;
		$jours = null;
		if(count($salles))
		{
			$idSalle = $salles[0]->idSalle;
			$idHoraire = $salles[0]->idHoraireCours;
			$jours = $salles[0]->jours;
		}
		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $idSalle,
			"idHoraireCours" => $idHoraire,
			"joursCours" => $jours
		]);

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("inscription/mutation",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle-origine","salle-origine","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle-destination","salle-destination","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("nombre","nombre","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm($_POST);
			return false;
		}

		$term = (int)$_POST["term"];
		$niveau = (int)$_POST["niveau"];
		$origine = (int)$_POST["salle-origine"];
		$destination = (int)$_POST['salle-destination'];
		$matricules = $_POST['matricules'];

		if($origine === $destination)
		{
			$this->resetForm(array_merge($_POST,Utility::getAlert("error","La salle d\'origine et la destination doit être different")));
			return false;
		}

		$dest = $this->repartition->getOne($destination);
		
		foreach ($matricules as $matricule) 
		{
			$this->repartition->updateOccupationById($destination);
			$this->repartition->updateOccupationById($origine,-1);

			$matricule = (int)$matricule;
			$this->mutation->create(["matriculeEtudiant","oldRepartition","newRepartition"],[$matricule,$origine,$destination]);
			$this->mutation->updateInscription(["idHoraireCours","joursCours","idSalle"],[$dest->idHoraireCours,$dest->jours,$dest->idSalle,$dest->idTerm,$matricule]);	
		}

		$this->index(Utility::getAlert("success"));
	}

	public function onExerciceChange()
	{
		$idExercice = (int)$_POST['idExercice'];
		$data["exercices"] = $this->exercice->getAll();
		$terms = $this->term->getAllByExercice($idExercice);
		$idTerm = 0;

		if(count($terms))
		{
			$idTerm = $terms[0]->idTerm;
		}
		$data["terms"] = $terms;

		$classes = $this->classe->getAll();
		$niveaux = [];
		
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idSalle = 0;
		$idHoraire = 0;
		$jours = null;
		if(count($salles))
		{
			$idSalle = $salles[0]->idSalle;
			$idHoraire = $salles[0]->idHoraireCours;
			$jours = $salles[0]->jours;
		}
		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $idSalle,
			"idHoraireCours" => $idHoraire,
			"joursCours" => $jours
		]);


		$data["values"] = ["exercice" => $_POST['idExercice']];

		$this->load->view("inscription/components/form_mutation",$data);
	}

	public function onTermChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];

		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$classes = $this->classe->getAll();
		$niveaux = [];
		
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idSalle = 0;
		$idHoraire = 0;
		$jours = null;
		if(count($salles))
		{
			$idSalle = $salles[0]->idSalle;
			$idHoraire = $salles[0]->idHoraireCours;
			$jours = $salles[0]->jours;
		}
		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $idSalle,
			"idHoraireCours" => $idHoraire,
			"joursCours" => $jours
		]);


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term']
		];

		$this->load->view("inscription/components/form_mutation",$data);
	}

	public function onClasseChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];
		$idClasse = (int)$_POST["classe"];

		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$niveaux = [];
		
		$idNiveau = 0;
		$niveaux = $this->niveau->getByClasse($idClasse);

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idSalle = 0;
		$idHoraire = 0;
		$jours = null;
		if(count($salles))
		{
			$idSalle = $salles[0]->idSalle;
			$idHoraire = $salles[0]->idHoraireCours;
			$jours = $salles[0]->jours;
		}
		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $idSalle,
			"idHoraireCours" => $idHoraire,
			"joursCours" => $jours
		]);


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term'],
			"classe" => $_POST['classe']
		];

		$this->load->view("inscription/components/form_mutation",$data);
	}

	public function onNiveauChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];
		$idClasse = (int)$_POST["classe"];

		$data["terms"] = $this->term->getAllByExercice($idExercice);
		
		$idNiveau = (int)$_POST['niveau'];


		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idSalle = 0;
		$idHoraire = 0;
		$jours = null;
		if(count($salles))
		{
			$idSalle = $salles[0]->idSalle;
			$idHoraire = $salles[0]->idHoraireCours;
			$jours = $salles[0]->jours;
		}
		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $idSalle,
			"idHoraireCours" => $idHoraire,
			"joursCours" => $jours
		]);


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term'],
			"classe" => $_POST['classe'],
			"niveau" => $_POST['niveau']
		];

		$this->load->view("inscription/components/form_mutation",$data);
	}

	public function onSalleChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];
		$idClasse = (int)$_POST["classe"];

		$data["terms"] = $this->term->getAllByExercice($idExercice);
		
		$idNiveau = (int)$_POST['niveau'];


		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idRepartition = (int)$_POST['salle-origine'];
		$rep = $this->repartition->getOne($idRepartition);

		$data["etudiants"] = $this->inscription->findEtudiants([
			"idTerm" => $idTerm,
			"idNiveau" => $idNiveau,
			"idSalle" => $rep->idSalle,
			"idHoraireCours" => $rep->idHoraireCours,
			"joursCours" => $rep->jours
		]);


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term'],
			"classe" => $_POST['classe'],
			"niveau" => $_POST['niveau'],
			"salle-origine" => $_POST['salle-origine']
		];

		$this->load->view("inscription/components/form_mutation",$data);
	}

	private function resetForm($values)
	{
		$data["active"] = 1;
		$data["lists"] = $this->mutation->getAll();

		$idExercice = 0;
		if(isset($values["exercice"]))
		{
			$idExercice = (int)$values['exercice'];
		}
		$data["exercices"] = $this->exercice->getAll();

		$idTerm = 0;
		if(isset($values["term"]))
		{
			$idTerm = (int)$values['term'];
		}
		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$idClasse = 0;
		if(isset($values["classe"]))
		{
			$idClasse = (int)$values["classe"];
		}
		$data["classes"] = $this->classe->getAll();
		
		$idNiveau = 0;
		if(isset($values["niveau"]))
		{
			$idNiveau = (int)$values['niveau'];
		}
		
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salleOrigines"] = $salles;
		$data["salleDestinations"] = $salles;

		$idRepartition = 0;
		if(isset($values["salle-origine"]))
		{
			$idRepartition = (int)$_POST['salle-origine'];
		}
		
		$rep = $this->repartition->getOne($idRepartition);

		$data["etudiants"] = [];

		if($rep)
		{
			$data["etudiants"] = $this->inscription->findEtudiants([
				"idTerm" => $idTerm,
				"idNiveau" => $idNiveau,
				"idSalle" => $rep->idSalle,
				"idHoraireCours" => $rep->idHoraireCours,
				"joursCours" => $rep->jours
			]);
		}
		


		$data["values"] = $values;

		$this->load->view("inscription/mutation",$data);
	}


}