<?php 

class PassingMark extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("PassingMarkModel","passing");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 2;
		$data["action"] = $action;
		$data["lists"] = $this->passing->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = [];

		$this->load->view("parametrage/passingMark",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("score","score","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("create",$_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$score = (int)$_POST["score"];
		$classe = (int)$_POST["classe"];

		if($this->passing->isExist($niveau))
		{
			$this->resetForm("create",array_merge(Utility::getAlert("error","Passing mank déjà enregistré"),$_POST));
			return false;
		}

		$this->passing->create(["idNiveau","scorePassingMark"],[$niveau,$score]);
		$this->resetForm("create",array_merge(Utility::getAlert("success"),["classe" => $classe]));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->passing->getOne($id);

		$data["active"] = 2;
		$data["action"] = "update";
		$data["lists"] = $this->passing->getAll();

		$data["values"] = [
			"id" => $res->idPassingMark,
			"classe" => $res->idClasse,
			"niveau" => $res->idNiveau,
			"score" => $res->scorePassingMark
		];

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($res->idClasse);

		$this->load->view("parametrage/passingMark",$data);

	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("score","score","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("update",$_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$score = (int)$_POST["score"];
		$classe = (int)$_POST["classe"];
		$id = (int)$_POST["id"];

		$toUpdate = $this->passing->getOne($id);

		if((int)$toUpdate->idNiveau !== $niveau)
		{
			if($this->passing->isExist($niveau))
			{
				$this->resetForm("update",array_merge(Utility::getAlert("error","Passing mank déjà enregistré"),$_POST));
				return false;
			}
		}

		$this->passing->update(["idNiveau","scorePassingMark"],[$niveau,$score,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->passing->delete($id);
		$this->index("create",Utility::getAlert("success","Passing mark supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["active"] = 2;
		$data["action"] = "create";
		$data["lists"] = $this->passing->getAllSearch("%".$query."%");

		$data["query"] = $query;

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = [];

		$this->load->view("parametrage/passingMark",$data);
	}



	/**
	 * Modifier le choix de niveau selon la classe choisi
	 * 
	 * */
	public function getNiveau()
	{
		$idClasse = (int)$_POST["idClasse"];

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$data["values"] = ["classe" => $idClasse];

		$this->load->view("parametrage/components/form_passingMark",$data);

	}

	/**
	 * Reset du formulaire
	 * 
	 * */
	private function resetForm($action="create",$values=null)
	{
		$data["active"] = 2;
		$data["action"] = $action;
		$data["lists"] = $this->passing->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse((int)$_POST['classe']);

		$this->load->view("parametrage/passingMark",$data);
	}



}