<?php 

class Etudiant extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("EtudiantModel","etudiant");
		$this->load->model("SessionModel","msession");
		$this->load->model("HoraireCoursModel","horaire");
		$this->load->model("CompanyModel","company");
		$this->load->model("ClasseModel","classe");
		$this->load->model("EtudiantPTModel","etudiantPT");
	}

	public function index($action="create",$values=null,$page=1)
	{
		$data["active"] = 1;
		$data["action"] = $action;

		$offset = ($page - 1) * LIMIT_PAGINATION;
		$data["lists"] = $this->etudiant->getAll($offset);

		$data["totals"] = $this->etudiant->getCount();
		$data["currentPage"] = $page;

		if($values)
		{
			$data["values"] = $values;
		}

		$data["sessions"] = $this->msession->getAll();
		$data["heures"] = $this->horaire->getAll();
		$data["compagnies"] = $this->company->getAll();
		$data["classes"] = $this->classe->getAll();

		$this->load->view("test/etudiant",$data);
	}

	public function page($number)
	{
		$page = (int)$number;
		if($page <= 0)
		{
			$page = 1;
		}

		if(isset($_GET["query"]))
		{
			$query = htmlspecialchars(trim($_GET['query']));
			$total = $this->etudiant->getCountSearch("%" .$query."%");
			$npages = ceil($total/LIMIT_PAGINATION);

			if($page > $npages)
			{
				$page = $npages;
			}
			$_POST['query'] = $query;
			$this->filter($page);
		}
		else
		{
			$total = $this->etudiant->getCount();
			$npages = ceil($total/LIMIT_PAGINATION);

			if($page > $npages)
			{
				$page = $npages;
			}
			$this->index("create",null,$page);
		}
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("session","session","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("nom","nom","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("type","type","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$session = (int)$_POST["session"];
		$nom = trim($_POST['nom']);
		$prenom = trim($_POST["prenom"]);
		$adresse = trim($_POST["adresse"]);
		$tel = trim($_POST["tel"]);
		$urgence = trim($_POST["urgence"]);
		$email = trim($_POST["email"]);
		$profession = trim($_POST["profession"]);
		$type = trim($_POST["type"]);
		$pref1 = (int)$_POST["pref1"];
		$pref2 = (int)$_POST["pref2"];
		$classe = trim($_POST["classe"]);

		$company = null;
		if($type === "company")
		{		
			$this->form_validation->set_rules("compagnie","compagnie","required",["required" => "Ce champ est obligatoire"]);

			if(!$this->form_validation->run())
			{
				$this->index("create",$_POST);
				return false;
			}
			$company = (int)$_POST["compagnie"];
		}
		$this->etudiant->create(["nom", "prenom", "adresse", "email", "contact", "contactUrgence", "profession", "idCompany", "codeClass", "typeEtudiant"], [$nom, $prenom, $adresse, $email, $tel, $urgence, $profession, $company, $classe, $type]);

		$idEtudiant = $this->etudiant->getLast();
		$tsession = $this->msession->getOne($session);
		$numeroPT = $this->etudiantPT->generateNumeroPT($tsession->numeroTerm);

		if($pref1 <= 0)
		{
			$pref1 = null;
		}

		if($pref2 <= 0)
		{
			$pref2 = null;
		}

		$this->etudiantPT->create(["numeroPT", "pref1", "pref2", "idEtudiant", "idSession"], [$numeroPT, $pref1, $pref2, $idEtudiant, $session]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->etudiant->getOne($id);
		$this->index("update",[
			"id" => $res->idEtudiant,
			"nom" => $res->nom,
			"prenom" => $res->prenom,
			"adresse" => $res->adresse,
			"tel" => $res->contact,
			"urgence" => $res->contactUrgence,
			"email" => $res->email,
			"profession" => $res->profession,
			"classe" => $res->codeClass,
			"session" => $res->idSession,
			"pref1" => $res->pref1,
			"pref2" => $res->pref2,
			"compagnie" => $res->idCompany,
			"type" => $res->typeEtudiant
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("nom","nom","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("type","type","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$nom = trim($_POST['nom']);
		$prenom = trim($_POST["prenom"]);
		$adresse = trim($_POST["adresse"]);
		$tel = trim($_POST["tel"]);
		$urgence = trim($_POST["urgence"]);
		$email = trim($_POST["email"]);
		$profession = trim($_POST["profession"]);
		$type = trim($_POST["type"]);
		$pref1 = (int)$_POST["pref1"];
		$pref2 = (int)$_POST["pref2"];
		$classe = trim($_POST["classe"]);
		$id = (int)$_POST["id"];

		$company = null;
		if($type === "company")
		{		
			$this->form_validation->set_rules("compagnie","compagnie","required",["required" => "Ce champ est obligatoire"]);

			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
			$company = (int)$_POST["compagnie"];
		}
		$this->etudiant->update(["nom", "prenom", "adresse", "email", "contact", "contactUrgence", "profession", "idCompany", "codeClass", "typeEtudiant"], [$nom, $prenom, $adresse, $email, $tel, $urgence, $profession, $company, $classe, $type,$id]);


		if($pref1 <= 0)
		{
			$pref1 = null;
		}

		if($pref2 <= 0)
		{
			$pref2 = null;
		}

		$this->etudiantPT->update(["pref1", "pref2"], [$pref1, $pref2,$id]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->etudiant->delete($id);
		$this->etudiantPT->delete($id);

		$this->index("create",Utility::getAlert("success","Etudiant supprimé"));
	}

	public function filter($page=1)
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}
		$data["active"] = 1;
		$data["action"] = "create";
		$offset = ($page - 1) * LIMIT_PAGINATION;
		$data["lists"] = $this->etudiant->getAllSearch("%".$query."%",$offset);
		$data["query"] = $query;

		$data["sessions"] = $this->msession->getAll();
		$data["heures"] = $this->horaire->getAll();
		$data["compagnies"] = $this->company->getAll();
		$data["classes"] = $this->classe->getAll();

		$data["totals"] = $this->etudiant->getCountSearch("%".$query."%");
		$data["currentPage"] = $page;
		
		$this->load->view("test/etudiant",$data);
	}

	public function insertCSV()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules('session', 'session', 'required');
		$idSession = (int)$_POST['session'];
		$file = $_FILES['csv'];

		if (!$this->form_validation->run()) 
		{
			$this->index("create",$_POST);
			return false;
		}
		if (FileManager::is_null($file)) 
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Choisir un fichier CSV")));
			return false;
		}
		if (!FileManager::verif_extension($file, ['csv'])) 
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Extension invalide")));
			return false;
		}

		$contents = file_get_contents($file['tmp_name']);
		$lines = explode("\n", $contents);
		unset($lines[0]);
		$lines = array_values($lines);

		foreach ($lines as $key => $line) {
			$etu = explode(",", $line);
			if (count($etu) === 10) {
				$nom = $etu[0];
				$prenom = $etu[1];
				$adresse = $etu[2];
				$email = $etu[3];
				$telephone = $etu[4];
				$urgence = $etu[5];
				$profession = $etu[6];
				$classe = $etu[7];
				$pref1 = $etu[8];
				$pref2 = $etu[9];

				$type = "normale";

				$company = NULL;

				$session = $this->msession->getOne($idSession);



				$this->etudiant->create(["nom", "prenom", "adresse", "email", "contact", "contactUrgence", "profession", "idCompany", "codeClass", "typeEtudiant"], [$nom, $prenom, $adresse, $email, $telephone, $urgence, $profession, $company, $classe, $type]);

				$idEtudiant = $this->etudiant->getLast();
				$numeroPT = $this->etudiantPT->generateNumeroPT($session->numeroTerm);
				if ($pref1 === "") 
				{
					$pref1 = NULL;
				}
				else
				{
					$pref1 = $this->horaire->getIdByDebut($pref1);
				}
				if ($pref2 === "") 
				{
					$pref2 = NULL;
				}
				else
				{
					$pref2 = $this->horaire->getIdByDebut($pref2);
				}

				$this->etudiantPT->create(["numeroPT", "pref1", "pref2", "idEtudiant", "idSession"], [$numeroPT, $pref1, $pref2, $idEtudiant, $idSession]);
			}
		}
		$this->index("create",Utility::getAlert("success"));
	}

	public function export()
	{
		$all = $this->etudiant->getAll();
		$data = [];

		foreach ($all as $value) {
			$data[] = (object)[
				"Numero PT" => $value->numeroPT,
				"Nom et prénoms" => $value->nom . " " . $value->prenom,
				"Adresse" => $value->adresse,
				"E-mail" => $value->email,
				"Contact" => $value->contact,
				"Contact d'urgence" => $value->contactUrgence,
				"Profession" => $value->profession,
				"Classe" => $value->codeClass,
				"preference_1" => $value->dpref1,
				"preference_2" => $value->dpref2
			];
		}
		ExportExcel::exporter('etudiant', $data);
	}


}