<?php 

class ResultatPTModel extends CI_Model{

	private $limit = LIMIT_PAGINATION;

	public function getAll($offset=0)
	{
		return DB::customQuery("SELECT * FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			INNER JOIN session ON session.idSession=resultatPT.idSession
			INNER JOIN term ON term.idTerm=session.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatPT.idNiveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			ORDER BY idResultatPT DESC
			LIMIT $this->limit
			OFFSET $offset");
	}

	public function getAllSearch($query,$offset=0)
	{
		return DB::customQuery("SELECT * FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			INNER JOIN session ON session.idSession=resultatPT.idSession
			INNER JOIN term ON term.idTerm=session.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatPT.idNiveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR resultatPT.numeroPT LIKE ?
			OR etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			ORDER BY idResultatPT DESC
			LIMIT $this->limit
			OFFSET $offset",
			[$query,$query,$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT resultatPT.*,etudiant.nom,etudiant.prenom
			FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			WHERE idResultatPT=?",
			[$id],false
		);
	}

	public function getCount()
	{
		$res = DB::customQuery("SELECT COUNT(idResultatPT) AS count FROM resultatPT",[],false);
		return (int)$res->count;
	}
	public function getCountSearch($query)
	{
		$res = DB::customQuery("SELECT COUNT(idResultatPT) AS count FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			INNER JOIN session ON session.idSession=resultatPT.idSession
			INNER JOIN term ON term.idTerm=session.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatPT.idNiveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR resultatPT.numeroPT LIKE ?
			OR etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?",
			[$query,$query,$query,$query,$query],false
		);
		return (int)$res->count;
	}

	public function getBySessionAndClasse($session,$classe)
	{
		return DB::customQuery("SELECT * FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			INNER JOIN session ON session.idSession=resultatPT.idSession
			INNER JOIN term ON term.idTerm=session.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatPT.idNiveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE resultatPT.idSession=?
			AND classe.idClasse=?
			ORDER BY idResultatPT DESC",
			[$session,$classe]
		);
	}
	public function getByNumeroPT($numeroPT)
	{
		return DB::customQuery("SELECT * FROM resultatPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=resultatPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			INNER JOIN session ON session.idSession=resultatPT.idSession
			INNER JOIN term ON term.idTerm=session.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatPT.idNiveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE resultatPT.numeroPT=?",
			[$numeroPT],false
		);
	}

	public function create($fields,$values)
	{
		DB::insert("resultatPT")
			->parametters($fields)
			->execute($values);
	}
	public function update($fields,$values)
	{
		DB::update("resultatPT")
			->parametters($fields)
			->where("idResultatPT","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("resultatPT")
			->where("idResultatPT","=")
			->execute([$id]);
	}

	/**
	 * Recuperer le rating ecrit via code classe
	 * 
	 * */
	public function getRatingEcrit($codeClasse,$scoreEcrit)
	{
		$res = DB::customQuery("SELECT scoring.rating FROM scoring
			INNER JOIN classe ON classe.idClasse=scoring.idClasse
			WHERE classe.codeClasse=?
			AND scoring.debutScore <= ?
			AND scoring.finScore >= ?",
			[$codeClasse,$scoreEcrit,$scoreEcrit],false
		);

		if(!$res)
		{
			return 0;
		}

		return (int)$res->rating;
	}

	/**
	 * On recupere le niveau de l'etudiant
	 * 
	 * On return si on ne trouve pas de correspondance => Aucun scoring enregistré pour cette classe et intervalle
	 * 
	 * */
	public function getNiveau($ecrit,$oral,$classe)
	{
		$ratingMoyen = floor(($ecrit + $oral) / 2);
		$res = DB::customQuery("SELECT * FROM scoring
			INNER JOIN classe ON classe.idClasse=scoring.idClasse
			WHERE classe.codeClasse=?
			AND debutScore <= ? 
			AND finScore >= ?",
			[$classe,$ratingMoyen,$ratingMoyen],false
		);
		if(!$res)
		{
			return null;
		}
		return $res->idNiveau;
	}

	/**
	 * Test doublon
	 * 
	 * */
	public function isExist($numeroPT)
	{
		$res = DB::select("resultatPT")
					->where("numeroPT","=")
					->fetchOne([$numeroPT]);
		if($res)
			return true;
		return false;
	}

}