<?php 

class Bareme extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("BaremeModel","bareme");
		$this->load->model("MatiereModel","matiere");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->bareme->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$data["matieres"] = $this->matiere->getAll();
		$classes = $this->classe->getAll();
		$niveaux = [];
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$this->load->view("examen/bareme",$data);
	}

	public function resetForm($action,$values)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["values"] = $values;

		$data["lists"] = $this->bareme->getAll();

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse((int)$values["classe"]);
		$data["matieres"] = $this->matiere->getAll();

		$this->load->view("examen/bareme",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("matieres[]","matiere","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("bareme","bareme","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("create",$_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$bareme = (int)$_POST['bareme'];
		$matieres = implode("-", $_POST['matieres']);

		if($this->bareme->isExist($niveau,$matieres))
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Barème déjà enregistré")));
			return false;
		}

		$this->bareme->create(["idNiveau","bareme","matieres"],[$niveau,$bareme,$matieres]);

		$this->index("create",Utility::getAlert("success"));

	}

	public function getOne()
	{
		$id = (int)$_POST["id"];
		$res = $this->bareme->getOne($id);

		$classe = $res->idClasse;

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($classe);
		$data["matieres"] = $this->matiere->getAll();

		$data["active"] = 1;
		$data["action"] = "update";
		$data["lists"] = $this->bareme->getAll();

		$data["values"] = [
			"id" => $res->idBareme,
			"niveau" => $res->idNiveau,
			"classe" => $res->idClasse,
			"matieres" => explode("-", $res->matieres),
			"bareme" => $res->bareme
		];

		$this->load->view("examen/bareme",$data);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("matieres[]","matiere","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("bareme","bareme","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("update",$_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$bareme = (int)$_POST['bareme'];
		$matieres = implode("-", $_POST['matieres']);
		$id = (int)$_POST["id"];

		$toUpdate = $this->bareme->getOne($id);

		if($niveau !== (int)$toUpdate->idNiveau || $matieres !== $toUpdate->matieres)
		{
			if($this->bareme->isExist($niveau,$matieres))
			{
				$this->index("update",array_merge($_POST,Utility::getAlert("error","Barème déjà enregistré")));
				return false;
			}
		}

		$this->bareme->update(["idNiveau","bareme","matieres"],[$niveau,$bareme,$matieres,$id]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];

		$this->bareme->delete($id);

		$this->index("create",Utility::getAlert("success","Barème supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->bareme->getAllSearch("%" . $query . "%");


		$data["matieres"] = $this->matiere->getAll();
		$classes = $this->classe->getAll();
		$niveaux = [];
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$data["query"] = $query;

		$this->load->view("examen/bareme",$data);
	}



}