<?php 

class Scoring extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		$this->load->model("ScoringModel","scoring");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->scoring->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = [];

		if(count($data["classes"]))
		{
			$data["niveaux"] = $this->niveau->getByClasse($data["classes"][0]->idClasse);
		}

		$this->load->view("test/scoring",$data);
	}
	public function resetForm($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->scoring->getAll();

		if($values)
		{
			$data["values"] = $values;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse((int)$values["classe"]);

		$this->load->view("test/scoring",$data);
	}
	public function getNiveau()
	{
		$idClasse = (int)$_POST["idClasse"];
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);
		$this->load->view("test/components/niveau_score",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("debut-score","debut","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("fin-score","fin","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("rating","rating","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("create",$_POST);
			return false;
		}

		$classe = (int)$_POST["classe"];
		$debut = (int)$_POST["debut-score"];
		$fin = (int)$_POST["fin-score"];
		$rating = (int)$_POST["rating"];
		$placement = trim($_POST["placement"]);
		$niveau = (int)$_POST["niveau"];

		/**
		 * Tester si le niveau existe déjà
		 * 
		 * */
		if($this->scoring->niveauExist($niveau))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Niveau existe déjà")));
			return false;
		}

		/**
		 * Tester si le debut et fin score existe déjà
		 * 
		 * */

		if($this->scoring->scoreExist($debut,$fin,$classe))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Interval de score existe déjà")));
			return false;
		}

		/**
		 * Tester si le rating existe dejà
		 * 
		 * */
		if($this->scoring->ratingExist($rating,$classe))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Rating existe déjà")));
			return false;
		}

		

		$this->scoring->create(["idClasse","debutScore","finScore","rating","placement","idNiveau"],[$classe,$debut,$fin,$rating,$placement,$niveau]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST['id'];
		$res = $this->scoring->getOne($id);

		$this->resetForm("update",[
			"id" => $res->idScoring,
			"debut-score" => $res->debutScore,
			"fin-score" => $res->finScore,
			"rating" => $res->rating,
			"placement" => $res->placement,
			"classe" => $res->idClasse,
			"niveau" => $res->idNiveau
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("classe","classe","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("debut-score","debut","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("fin-score","fin","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("rating","rating","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("update",$_POST);
			return false;
		}

		$classe = (int)$_POST["classe"];
		$debut = (int)$_POST["debut-score"];
		$fin = (int)$_POST["fin-score"];
		$rating = (int)$_POST["rating"];
		$placement = trim($_POST["placement"]);
		$niveau = (int)$_POST["niveau"];
		$id = (int)$_POST["id"];

		$toUpdate = $this->scoring->getOne($id);

		if($niveau !== (int)$toUpdate->idNiveau)
		{
			if($this->scoring->niveauExist($niveau))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Niveau existe déjà")));
				return false;
			}
		}
		if($debut !== (int)$toUpdate->debutScore || $fin !== (int)$toUpdate->finScore)
		{
			if($this->scoring->scoreExist($debut,$fin,$classe))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Interval de score existe déjà")));
				return false;
			}
		}
		if($rating !== (int)$toUpdate->rating)
		{
			if($this->scoring->ratingExist($rating,$classe))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Rating existe déjà")));
				return false;
			}
		}

		$this->scoring->update(["idClasse","debutScore","finScore","rating","placement","idNiveau"],[$classe,$debut,$fin,$rating,$placement,$niveau,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->scoring->getAllSearch("%".$query."%");

		$data["query"] = $query;

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = [];

		if(count($data["classes"]))
		{
			$data["niveaux"] = $this->niveau->getByClasse($data["classes"][0]->idClasse);
		}

		$this->load->view("test/scoring",$data);
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->scoring->delete($id);
		$this->index("create",Utility::getAlert("success","Scoring supprimé"));
	}



}