<?php 

class Resultat extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("ResultatExamenModel","resultat");
		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
		$this->load->model("BaremeModel","bareme");

		$this->load->model("NoteExamenModel","note");
		$this->load->model("InscriptionCoursModel","inscription");
	}

	public function index($values=null)
	{
		$data["active"] = 1;
		$data["lists"] = $this->resultat->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		if(count($exercices))
		{
			$data["terms"] = $this->term->getAllByExercice($exercices[0]->idExercice);
		}

		$classes = $this->classe->getAll();
		$niveaux = [];

		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}
		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		if(count($niveaux))
		{
			$data["matieres"] = $this->bareme->getMatieresByNiveau($niveaux[0]->idNiveau);
		}

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("examen/resultat",$data);
	}
	public function getInfoByClasse()
	{
		$idClasse = (int)$_POST["classe"];
		$niveaux = $this->niveau->getByClasse($idClasse);

		if(count($niveaux))
		{
			$data["matieres"] = $this->bareme->getMatieresByNiveau($niveaux[0]->idNiveau);
		}

		$data["niveaux"] = $niveaux;

		$this->load->view("examen/components/form_resultExamen",$data);
	}

	public function getInfoByNiveau()
	{
		$idClasse = (int)$_POST["classe"];
		$idNiveau = (int)$_POST['niveau'];
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$data["matieres"] = $this->bareme->getMatieresByNiveau($idNiveau);

		$data["values"] = ["niveau" => trim($_POST["niveau"])];

		$this->load->view("examen/components/form_resultExamen",$data);
	}

	public function resetFormList($values)
	{
		$data["active"] = 1;
		$data["lists"] = $this->resultat->getAll();

		$exercices = $this->exercice->getAll();
		$data["exercices"] = $exercices;
		if(isset($values["exercice"]))
		{
			$data["terms"] = $this->term->getAllByExercice((int)$values["exercice"]);
		}

		$classes = $this->classe->getAll();
		$niveaux = [];

		if(isset($values["classe"]))
		{
			$niveaux = $this->niveau->getByClasse((int)$values["classe"]);
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		if(isset($values["niveau"]))
		{
			$data["matieres"] = $this->bareme->getMatieresByNiveau($values["niveau"]);
		}

		$data["values"] = $values;


		$this->load->view("examen/resultat",$data);
	}

	public function generateList()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("matiere","matiere","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetFormList($_POST);
			return false;
		}

		$niveau = (int)$_POST["niveau"];
		$term = (int)$_POST['term'];
		$matiere = trim($_POST['matiere']);

		$bareme = $this->bareme->getByNiveauAndMatiere($niveau, $matiere)->bareme;

		if($this->note->isEmpty($niveau,$term,$matiere))
		{
			$etudiants = $this->inscription->getEtudiantByTermAndNiveau($niveau,$term);

			foreach($etudiants as $etu)
			{
				$this->note->create(["matriculeEtudiant","idTerm","idNiveau","matiere","bareme"],[$etu->matriculeEtudiant,$term,$niveau,$matiere,$bareme]);
			}
		}

		$this->resetFormList(array_merge(
					$_POST,
					[
					"open_modal" => "openModalResult()"
					]
				));
	}

	public function getList()
	{
		$niveau = (int)$_POST["niveau"];
		$term = (int)$_POST['term'];
		$matiere = trim($_POST['matiere']);

		$session = $this->term->getOne($term);
		$niv = $this->niveau->getOne($niveau);

		$data["session"] = $session;
		$data["niveau"] = $niv;
		$data["matiere"] = $matiere;

		$data["etudiants"] = $this->note->getListEtudiants($niveau,$term,$matiere);

		$this->load->view("examen/components/modal_resultat",$data);
	} 

	public function saisieNote()
	{
		$notes = $_POST['notes'];
		$ids = $_POST['ids'];

		foreach($notes as $k => $note)
		{
			if(trim($note) === "")
			{
				$note = null;
			}
			else
			{
				$note = (float)$note;
			}

			$this->note->update(["note"],[$note,$ids[$k]]);
		}
	}

}