<?php 

class Fermeture extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("FermetureModel","fermeture");

		$this->load->model("ExerciceModel","exercice");
		$this->load->model("TermModel","term");
		$this->load->model("HoraireCoursModel","horaire");
		$this->load->model("ClasseModel","classe");
		$this->load->model("NiveauModel","niveau");
		$this->load->model("RepartitionCoursModel","repartition");
		$this->load->model("InscriptionCoursModel","inscription");

		$this->load->model("EtudiantCoursModel","etuCours");
	}

	public function index($values=null)
	{
		$data["active"] = 2;

		$data["lists"] = $this->fermeture->getAll();

		$exercices = $this->exercice->getAll();
		$terms = [];
		$idTerm = 0;

		if($exercices)
		{
			$terms = $this->term->getAllByExercice($exercices[0]->idExercice); 
		}
		if(count($terms))
		{
			$idTerm = (int)$terms[0]->idTerm;
		}

		$data["exercices"] = $exercices;
		$data["terms"] = $terms;

		$classes = $this->classe->getAll();
		$niveaux = [];
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("inscription/fermeture",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("term","term","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("niveau","niveau","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle","salle","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm($_POST);
			return false;
		}

		$term = (int)$_POST["term"];
		$niveau = (int)$_POST["niveau"];
		$salle = (int)$_POST["salle"];

		$rep = $this->repartition->getOne($salle);

		$etudiants = $this->inscription->findEtudiants([
			"idTerm" => $term,
			"idNiveau" => $niveau,
			"idSalle" => $rep->idSalle,
			"idHoraireCours" => $rep->idHoraireCours,
			"joursCours" => $rep->jours
		]);


		foreach($etudiants as $etu)
		{
			$this->fermeture->create(["idTerm","idNiveau","idSalle","idHoraireCours","joursCours","idEtudiant"],[$term,$niveau,$rep->idSalle,$rep->idHoraireCours,$rep->jours,$etu->idEtudiant]);

			$this->inscription->delete($etu->idInscriptionCours);

			if(!$this->inscription->getByMatricule($etu->matriculeEtudiant))
			{
				$this->etuCours->delete($etu->matriculeEtudiant);
			}

			$this->inscription->deleteFacture($etu->idInscriptionCours);
		}

		$this->repartition->delete($salle);

		$this->index(Utility::getAlert("success","Fermeture de la salle effectué"));
	}

	public function onExerciceChange()
	{
		$idExercice = (int)$_POST['idExercice'];
		$data["exercices"] = $this->exercice->getAll();
		$terms = $this->term->getAllByExercice($idExercice);
		$idTerm = 0;

		if(count($terms))
		{
			$idTerm = $terms[0]->idTerm;
		}
		$data["terms"] = $terms;

		$classes = $this->classe->getAll();
		$niveaux = [];
		
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;


		$data["values"] = ["exercice" => $_POST['idExercice']];

		$this->load->view("inscription/components/form_fermeture",$data);
	}

	public function onTermChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];

		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$classes = $this->classe->getAll();
		$niveaux = [];
		
		$idNiveau = 0;
		if(count($classes))
		{
			$niveaux = $this->niveau->getByClasse($classes[0]->idClasse);
		}

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $classes;
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;

		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term']
		];

		$this->load->view("inscription/components/form_fermeture",$data);
	}

	public function onClasseChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];
		$idClasse = (int)$_POST["classe"];

		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$niveaux = [];
		
		$idNiveau = 0;
		$niveaux = $this->niveau->getByClasse($idClasse);

		if(count($niveaux))
		{
			$idNiveau = (int)$niveaux[0]->idNiveau;
		}

		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $niveaux;

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term'],
			"classe" => $_POST['classe']
		];

		$this->load->view("inscription/components/form_fermeture",$data);
	}

	public function onNiveauChange()
	{
		$idExercice = (int)$_POST['exercice'];
		$data["exercices"] = $this->exercice->getAll();
		$idTerm = (int)$_POST['term'];
		$idClasse = (int)$_POST["classe"];

		$data["terms"] = $this->term->getAllByExercice($idExercice);
		
		$idNiveau = (int)$_POST['niveau'];


		$data["classes"] = $this->classe->getAll();
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;


		$data["values"] = [
			"exercice" => $_POST['exercice'],
			"term" => $_POST['term'],
			"classe" => $_POST['classe'],
			"niveau" => $_POST['niveau']
		];

		$this->load->view("inscription/components/form_fermeture",$data);
	}

	private function resetForm($values)
	{
		$data["active"] = 2;
		$data["lists"] = $this->fermeture->getAll();

		$idExercice = 0;
		if(isset($values["exercice"]))
		{
			$idExercice = (int)$values['exercice'];
		}
		$data["exercices"] = $this->exercice->getAll();

		$idTerm = 0;
		if(isset($values["term"]))
		{
			$idTerm = (int)$values['term'];
		}
		$data["terms"] = $this->term->getAllByExercice($idExercice);

		$idClasse = 0;
		if(isset($values["classe"]))
		{
			$idClasse = (int)$values["classe"];
		}
		$data["classes"] = $this->classe->getAll();
		
		$idNiveau = 0;
		if(isset($values["niveau"]))
		{
			$idNiveau = (int)$values['niveau'];
		}
		
		$data["niveaux"] = $this->niveau->getByClasse($idClasse);

		$salles = $this->repartition->findSalleByNiveauAndTerm($idNiveau,$idTerm);
		$data["salles"] = $salles;

		$idRepartition = 0;
		if(isset($values["salle"]))
		{
			$idRepartition = (int)$_POST['salle'];
		}


		$data["values"] = $values;

		$this->load->view("inscription/fermeture",$data);
	}


}