<?php 

class Classe extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("ClasseModel","classe");
	}

	public function index($action="create",$values=null)
	{
		$data["action"] = $action;
		$data["active"] = 1;
		$data["lists"] = $this->classe->getAll();
		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("parametrage/classe",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");

		$this->form_validation->set_rules("code","code","required|is_unique[classe.codeClasse]",[
			"required" => "Ce champ est obligatoire",
			"is_unique" => "Le code classe doit être unique"
		]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$code = trim($_POST["code"]);
		$description = trim($_POST["description"]);

		$this->classe->create(["codeClasse","description"],[$code,$description]);

		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = trim($_POST["id"]);

		$res = $this->classe->getOne($id);

		$this->index("update",[
			"id" => $res->idClasse,
			"code" => $res->codeClasse,
			"description" => $res->description
		]);
	}

	public function update()
	{
		$id = trim($_POST["id"]);
		$code = trim($_POST["code"]);
		$description = trim($_POST["description"]);
		$res = $this->classe->getOne($id);

		$this->form_validation->set_rules("code","code","required",["required" => "Ce champ est obligatoire"]);
		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		if($code !== $res->codeClasse)
		{
			$this->form_validation->set_rules("code","code","is_unique[classe.codeClasse]",["is_unique" => "Le code classe doit être unique"]);
			if(!$this->form_validation->run())
			{
				$this->index("update",$_POST);
				return false;
			}
		}

		$this->classe->update(["codeClasse","description"],[$code,$description,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->classe->delete($id);
		$this->index("create",Utility::getAlert("success","Classe supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index("create");
			return false;
		}

		$data["action"] = "create";
		$data["active"] = 1;
		$data["lists"] = $this->classe->getAllSearch("%".$query."%");
		$data["query"] = $query;

		$this->load->view("parametrage/classe",$data);
	}


}