<?php 

class Pointage extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("PointageModel","pointage");
		$this->load->model("EnseignantModel","enseignant");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["lists"] = $this->pointage->getAll();

		$data["action"] = $action;

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("pointage/pointage",$data);
	}

	public function getInfo()
	{
		$matricule = trim($_POST["matricule"]);
		$ens = $this->enseignant->getOne($matricule);

		$data["values"] = [
			"fullname" => null,
			"heure" => null
		];

		if($ens)
		{
			$data["values"] = [
				"fullname" => $ens->nomEnseignant ." ".$ens->prenomEnseignant,
				"heure" => date("H:i")
			];
		}

		$this->load->view("pointage/components/form_pointage",$data);
		
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("matricule","matricule","required",["required" => "champ est obligatoire"]);
		$this->form_validation->set_rules("heure","heure","required",["required" => "champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("create",$_POST);
			return false;
		}

		$matricule = trim($_POST["matricule"]);
		$date = date("Y-m-d");
		$heure = trim($_POST["heure"]);

		$ens = $this->enseignant->getOne($matricule);
		if(!$ens)
		{
			$this->form_validation->set_rules("matricule","matricule","in_list[x01x02x03x04x05fd9a]",[
				"in_list" => "Matricule inexistant"
			]);
			$this->form_validation->run();
			$this->index("create",$_POST);
			return false;
		}

		if($this->pointage->isExist($matricule,$date))
		{
			$this->index("create",array_merge($_POST,Utility::getAlert("error","Pointage déjà effectuée")));
			return false;
		}

		$this->pointage->create(["matriculeEnseignant","datePointage","heureArrive"],[$matricule,$date,$heure]);

		$this->index("create",Utility::getAlert("success"));

	}

	public function getOne()
	{
		$id = (int)$_POST['id'];
		$res = $this->pointage->getOne($id);

		$this->index("update",[
			"id" => $res->idPointage,
			"matricule" => $res->matriculeEnseignant,
			"fullname" => $res->nomEnseignant . " " . $res->prenomEnseignant,
			"heure" => $res->heureArrive
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("heure","heure","required",["required" => "champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->index("update",$_POST);
			return false;
		}

		$heure = trim($_POST['heure']);
		$id = (int)$_POST["id"];

		$this->pointage->update(["heureArrive"],[$heure,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];

		$this->pointage->delete($id);

		$this->index("create",Utility::getAlert("success","Pointage supprimé"));
	}

	public function filter()
	{
		$query = trim($_POST['query']);

		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["lists"] = $this->pointage->getAllSearch("%".$query."%");

		$data["action"] = "create";

		$data["query"] = $query;

		$this->load->view("pointage/pointage",$data);
	}

	public function out()
	{
		$id = (int)$_POST['id'];
		$this->pointage->update(["heureDepart"],[date("H:i"),$id]);
		$this->index("create",Utility::getAlert("success","Pointage effectué"));
	}


}