<?php 

class RepartitionPT extends CI_Controller{

	public function __construct()
	{
		parent::__construct();
		if(!isset($_SESSION['userID'])){
			redirect(base_url("login"));
            exit;
		}
		$this->load->model("RepartitionPTModel","repartition");
		$this->load->model("SessionModel","msession");
		$this->load->model("MatierePTModel","matiere");
		$this->load->model("HorairePTModel","horaire");
		$this->load->model("EnseignantModel","enseignant");
		$this->load->model("SalleModel","salle");
	}

	public function index($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->repartition->getAll();

		$data["sessions"] = $this->msession->getAll();
		$matieres = $this->matiere->getAll();
		$data["matieres"] = $matieres;
		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();
		$data["heures"] = [];

		if(count($matieres))
		{
			$data["heures"] = $this->horaire->getByMatiere($matieres[0]->idMatierePT);
		}

		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("test/repartition",$data);
	}

	/**
	 * 
	 * renvoi du formulaire pre-rempli
	 * 
	 * */
	public function resetForm($action="create",$values=null)
	{
		$data["active"] = 1;
		$data["action"] = $action;
		$data["lists"] = $this->repartition->getAll();

		$data["sessions"] = $this->msession->getAll();
		$matieres = $this->matiere->getAll();
		$data["matieres"] = $matieres;
		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();

		$data["heures"] = $this->horaire->getByMatiere((int)$values["matiere"]);


		if($values)
		{
			$data["values"] = $values;
		}

		$this->load->view("test/repartition",$data);
	}

	public function create()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("session","session","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("matiere","matiere","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date","date","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("heure","heure","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("enseignant","enseignant","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle","salle","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("create",$_POST);
			return false;
		}

		$session = (int)$_POST["session"];
		$matiere = (int)$_POST["matiere"];
		$date = trim($_POST["date"]);
		$heure = (int)$_POST["heure"];
		$enseignant = trim($_POST["enseignant"]);
		$salle = (int)$_POST["salle"];


		if($this->repartition->isExist($session,$matiere,$date,$heure,$enseignant,$salle))
		{
			$this->resetForm("create",array_merge($_POST,Utility::getAlert("error","Repartition déjà enregistré")));
			return false;
		}

		$this->repartition->create(["idSession","idMatierePT","dateTest","idHorairePT","matriculeEnseignant","idSalle"],[$session,$matiere,$date,$heure,$enseignant,$salle]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function getOne()
	{
		$id = (int)$_POST['id'];
		$res = $this->repartition->getOne($id);
		$this->resetForm("update",[
			"id" => $res->idRepartitionPT,
			"session" => $res->idSession,
			"matiere" => $res->idMatierePT,
			"date" => $res->dateTest,
			"horaire" => $res->idHorairePT,
			"enseignant" => $res->matriculeEnseignant,
			"salle" => $res->idSalle
		]);
	}

	public function update()
	{
		$this->form_validation->set_error_delimiters("","");
		$this->form_validation->set_rules("session","session","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("matiere","matiere","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("date","date","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("heure","heure","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("enseignant","enseignant","required",["required" => "Ce champ est obligatoire"]);
		$this->form_validation->set_rules("salle","salle","required",["required" => "Ce champ est obligatoire"]);

		if(!$this->form_validation->run())
		{
			$this->resetForm("update",$_POST);
			return false;
		}

		$session = (int)$_POST["session"];
		$matiere = (int)$_POST["matiere"];
		$date = trim($_POST["date"]);
		$heure = (int)$_POST["heure"];
		$enseignant = trim($_POST["enseignant"]);
		$salle = (int)$_POST["salle"];
		$id = (int)$_POST["id"];

		$res = $this->repartition->getOne($id);

		if($session !== (int)$res->idSession ||
			$matiere !== (int)$res->idMatierePT ||
			$date !== $res->dateTest ||
			$heure !== (int)$res->idHorairePT ||
			$enseignant !== $res->matriculeEnseignant ||
			$salle !== (int)$res->idSalle)
		{

			if($this->repartition->isExist($session,$matiere,$date,$heure,$enseignant,$salle))
			{
				$this->resetForm("update",array_merge($_POST,Utility::getAlert("error","Repartition déjà enregistré")));
				return false;
			}
				
		}

		$this->repartition->update(["idSession","idMatierePT","dateTest","idHorairePT","matriculeEnseignant","idSalle"],[$session,$matiere,$date,$heure,$enseignant,$salle,$id]);
		$this->index("create",Utility::getAlert("success"));
	}

	public function delete()
	{
		$id = (int)$_POST["id"];
		$this->repartition->delete($id);
		$this->index("create",Utility::getAlert("success","Repartition supprimé"));
	}
	public function filter()
	{
		$query = trim($_POST["query"]);
		if($query === "")
		{
			$this->index();
			return false;
		}

		$data["active"] = 1;
		$data["action"] = "create";
		$data["lists"] = $this->repartition->getAllSearch("%".$query."%");

		$data["sessions"] = $this->msession->getAll();
		$matieres = $this->matiere->getAll();
		$data["matieres"] = $matieres;
		$data["enseignants"] = $this->enseignant->getAll();
		$data["salles"] = $this->salle->getAll();
		$data["heures"] = [];

		if(count($matieres))
		{
			$data["heures"] = $this->horaire->getByMatiere($matieres[0]->idMatierePT);
		}

		$data["query"] = $query;

		$this->load->view("test/repartition",$data);
	}

	/**
	 * 
	 * Rafraichir le select horaire lorsque la matiere a modifié
	 * 
	 * */
	public function getHoraire()
	{
		$idMatiere = (int)$_POST["idMatiere"];
		$data["heures"] = $this->horaire->getByMatiere($idMatiere);

		$this->load->view("test/components/horaire_repartition",$data);
	}


}