<?php 

class InscriptionPTModel extends CI_Model{

	private $limit = LIMIT_PAGINATION;

	public function getAll($offset=0)
	{
		return DB::customQuery("SELECT inscriptionPT.*,etudiant.*,
			salleEcrit.nomSalle AS s_ecrit,
			salleOral.nomSalle AS s_oral,
			remise.nomRemise
			FROM inscriptionPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT
			INNER JOIN etudiant ON etudiantPT.idEtudiant=etudiant.idEtudiant
			INNER JOIN repartitionPT AS rEcrit ON rEcrit.idRepartitionPT=inscriptionPT.salleEcrit
			INNER JOIN repartitionPT AS rOral ON rOral.idRepartitionPT=inscriptionPT.salleOral
			INNER JOIN salle AS salleEcrit ON salleEcrit.idSalle=rEcrit.idSalle
			INNER JOIN salle AS salleOral ON salleOral.idSalle=rOral.idSalle
			LEFT JOIN remise ON remise.idRemise=inscriptionPT.idRemise
			ORDER BY createdAt DESC
			LIMIT $this->limit
			OFFSET $offset");
	}
	public function getAllSearch($query,$offset=0)
	{
		return DB::customQuery("SELECT inscriptionPT.*,etudiant.*,
			salleEcrit.nomSalle AS s_ecrit,
			salleOral.nomSalle AS s_oral
			FROM inscriptionPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT
			INNER JOIN etudiant ON etudiantPT.idEtudiant=etudiant.idEtudiant
			INNER JOIN repartitionPT AS rEcrit ON rEcrit.idRepartitionPT=inscriptionPT.salleEcrit
			INNER JOIN repartitionPT AS rOral ON rOral.idRepartitionPT=inscriptionPT.salleOral
			INNER JOIN salle AS salleEcrit ON salleEcrit.idSalle=rEcrit.idSalle
			INNER JOIN salle AS salleOral ON salleOral.idSalle=rOral.idSalle
			WHERE etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR etudiant.codeClass LIKE ?
			OR inscriptionPT.numeroPT LIKE ?
			ORDER BY createdAt DESC
			LIMIT $this->limit
			OFFSET $offset",
			[$query,$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT inscriptionPT.*,etudiant.* ,etudiantPT.idSession
			FROM inscriptionPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant
			WHERE idInscriptionPT=?",
			[$id],false
		);
	}

	public function getCount()
	{
		$res = DB::customQuery("SELECT COUNT(idInscriptionPT) AS count FROM inscriptionPT",[],false);
		return (int)$res->count;
	}
	public function getCountSearch($query)
	{
		$res = DB::customQuery("SELECT COUNT(idInscriptionPT) AS count
			FROM inscriptionPT
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT
			INNER JOIN etudiant ON etudiantPT.idEtudiant=etudiant.idEtudiant
			INNER JOIN repartitionPT AS rEcrit ON rEcrit.idRepartitionPT=inscriptionPT.salleEcrit
			INNER JOIN repartitionPT AS rOral ON rOral.idRepartitionPT=inscriptionPT.salleOral
			INNER JOIN salle AS salleEcrit ON salleEcrit.idSalle=rEcrit.idSalle
			INNER JOIN salle AS salleOral ON salleOral.idSalle=rOral.idSalle
			WHERE etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR etudiant.codeClass LIKE ?
			OR inscriptionPT.numeroPT LIKE ?
			ORDER BY createdAt DESC",
			[$query,$query,$query,$query],false
		);
		return (int)$res->count;
	}

	public function create($fields,$values)
	{
		DB::insert("inscriptionPT")
			->parametters($fields)
			->execute($values);
	}
	public function update($fields,$values)
	{
		DB::update("inscriptionPT")
			->parametters($fields)
			->where("idInscriptionPT","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("inscriptionPT")
			->where("idInscriptionPT","=")
			->execute([$id]);
	}


	/**
	 * 
	 * Verification doublon inscription pt
	 * 
	 * */
	public function isInscrit($date, $numeroPT)
	{
		$res = DB::customQuery("SELECT * FROM inscriptionPT WHERE dateTest=? AND numeroPT=?",[$date,$numeroPT], false);
		if ($res)
			return true;
		return false;
	}

	/**
	 * 
	 * Generer l'heure de l'inscription aux cours
	 * 
	 * */

	public function getHeureInscription($dateInscription)
	{
		$dureeInscription = DB::select("dureeInscription")
			->where("idDuree", "=")
			->fetchOne([1]);

		$nombreEtudiant = (int)$dureeInscription->nombreEtudiant;

		$duree = (int)$dureeInscription->dureeInscription;
		$start = $dureeInscription->heureDebut;

		$last = DB::customQuery("SELECT MAX(heureInscription) AS max FROM inscriptionPT 
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT 
			INNER JOIN session ON session.idSession=etudiantPT.idSession 
			WHERE dateInscription=?", 
			[$dateInscription],false
		);

		if (!$last->max) 
		{
			return $start;
		}
		
		$all = DB::customQuery("SELECT * FROM inscriptionPT 
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT 
			INNER JOIN session ON session.idSession=etudiantPT.idSession 
			WHERE dateInscription=?",
			[$dateInscription]
		);

		if (count($all) % $nombreEtudiant === 0) 
		{
			$parts = explode(":", $last->max);
			$minutes = ((int)$parts[0] * 60) + (int)$parts[1] + $duree;

			return str_pad(floor($minutes / 60), 2, "0", STR_PAD_LEFT) . ":" . str_pad($minutes % 60, 2, "0", STR_PAD_LEFT);
		}
		return $last->max;
	}

	/**
	 * 
	 * Recupere inscription pour imprimer
	 * 
	 * */
	public function getRecu($id)
	{
		return DB::customQuery("SELECT inscriptionPT.*,etudiant.*,
			session.*,term.*,exercice.*,
			salleOral.nomSalle AS s_oral,
			salleEcrit.nomSalle AS s_ecrit 
			FROM inscriptionPT 
			INNER JOIN etudiantPT ON etudiantPT.numeroPT=inscriptionPT.numeroPT 
			INNER JOIN etudiant ON etudiant.idEtudiant=etudiantPT.idEtudiant 
			INNER JOIN session ON session.idSession=etudiantPT.idSession 
			INNER JOIN term ON term.idTerm=session.idTerm 
			INNER JOIN exercice ON exercice.idExercice=term.idExercice 
			INNER JOIN repartitionPT AS rOral ON rOral.idRepartitionPT=inscriptionPT.salleOral 
			INNER JOIN repartitionPT AS rEcrit ON rEcrit.idRepartitionPT=inscriptionPT.salleEcrit
			INNER JOIN salle AS salleOral ON rOral.idSalle=salleOral.idSalle
			INNER JOIN salle AS salleEcrit ON salleEcrit.idSalle=rEcrit.idSalle
			WHERE inscriptionPT.idInscriptionPT=?", 
			[$id],false
		);
	}


}