<?php 

class NiveauModel extends CI_Model{

	public function getAll()
	{
		return DB::customQuery("SELECT niveau.*,classe.codeClasse FROM niveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse 
			ORDER BY niveau.idClasse ASC,degreeNiveau ASC");
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT niveau.*,classe.codeClasse 
			FROM niveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE idNiveau=?",
			[$id],false
		);
	}

	public function getAllSearch($query)
	{
		return DB::customQuery("SELECT niveau.*,classe.codeClasse FROM niveau
			INNER JOIN classe ON classe.idClasse=niveau.idClasse
			WHERE niveau.codeNiveau LIKE ?
			OR classe.codeClasse LIKE ? 
			ORDER BY niveau.idClasse ASC,degreeNiveau ASC",
			[$query,$query]
		);
	}

	public function create($fields,$values)
	{
		DB::insert("niveau")->parametters($fields)->execute($values);
	}
	public function update($fields,$values)
	{
		DB::update("niveau")
			->parametters($fields)
			->where("idNiveau","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("niveau")->where("idNiveau","=")->execute([$id]);
	}


	/**
	 * Verifie si le degree est deja enregistree pour une classe
	 * 
	 * */

	public function degreeExist($idClasse,$degree)
	{
		$res = DB::customQuery("SELECT * FROM niveau WHERE idClasse=? AND degreeNiveau=?",[$idClasse,$degree],false);
		if($res)
			return true;
		return false;
	}

	/**
	 * Verifie si le code niveau est deja enregistree pour une classe
	 * 
	 * */

	public function codeExist($idClasse,$code)
	{
		$res = DB::customQuery("SELECT * FROM niveau WHERE idClasse=? AND codeNiveau=?",[$idClasse,$code],false);
		if($res)
			return true;
		return false;
	}

	/**
	 * Recuperes les niveau d'une classe
	 * 
	 * */
	public function getByClasse($idClasse)
	{
		return DB::select("niveau")
					->where("idClasse","=")
					->execute([$idClasse]);
	}

	/**
	 * Verifie si un niveau a du categorie
	 * 
	 * */
	public function hasCategorie($id)
	{
		$res = DB::select("niveau")
					->where("idNiveau","=")
					->and("categorie","!=")
					->fetchOne([$id,0]);
		if($res)
		{
			return true;
		}
		return false;
	}

	/**
	 * Recupere les jours de cours via id
	 * 
	 * */
	public function getJoursCours($id)
	{
		$res = $this->getOne($id);
		
		if($res)
			return explode("|", $res->joursCours);
		return [];
	}

	/**
	 * Recuperer le niveau suivant
	 * 
	 * */
	public function getNextLevel($niveau)
	{
		$current = $this->getOne($niveau);
		$next = DB::select("niveau")
					->where("degreeNiveau",">")
					->and("idClasse","=")
					->order(["degreeNiveau" => "ASC"])
					->fetchOne([$current->degreeNiveau,$current->idClasse]);
		if($next)
			return (int)$next->idNiveau;
		return (int)$niveau;
	}


}