<?php  

class EtudiantModel extends CI_Model{

	private $limit = LIMIT_PAGINATION;

	public function getByMatricule($matricule)
	{
		return DB::select("etudiant")
					->where("matricule","=")
					->fetchOne([$matricule]);
	}

	public function getAll($offset=0)
	{
		return DB::customQuery("SELECT etudiant.*, 
			etudiantPT.numeroPT,
			hc1.debutCours AS dpref1,hc1.finCours AS fpref1,
			hc2.debutCours AS dpref2,hc2.finCours AS fpref2
			FROM etudiant
			LEFT JOIN etudiantPT ON etudiant.idEtudiant=etudiantPT.idEtudiant
			LEFT JOIN horaireCours AS hc1 ON hc1.idHoraireCours=etudiantPT.pref1
			LEFT JOIN horaireCours AS hc2 ON hc2.idHoraireCours=etudiantPT.pref2
			ORDER BY numeroPT DESC
			LIMIT $this->limit
			OFFSET $offset");
	}

	public function getAllSearch($query,$offset=0)
	{
		return DB::customQuery("SELECT etudiant.*, 
			etudiantPT.numeroPT,
			hc1.debutCours AS dpref1,hc1.finCours AS fpref1,
			hc2.debutCours AS dpref2,hc2.finCours AS fpref2
			FROM etudiant
			LEFT JOIN etudiantPT ON etudiant.idEtudiant=etudiantPT.idEtudiant
			LEFT JOIN horaireCours AS hc1 ON hc1.idHoraireCours=etudiantPT.pref1
			LEFT JOIN horaireCours AS hc2 ON hc2.idHoraireCours=etudiantPT.pref2
			WHERE etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR etudiantPT.numeroPT LIKE ?
			ORDER BY numeroPT DESC
			LIMIT $this->limit
			OFFSET $offset",
			[$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT * FROM etudiant 
			LEFT JOIN etudiantPT ON etudiantPT.idEtudiant=etudiant.idEtudiant
			WHERE etudiant.idEtudiant=?",
			[$id],false
		);
	}

	
	public function getOneByMatricule($matricule)
	{
		return DB::customQuery("SELECT * FROM etudiant 
			WHERE etudiant.matricule=?",
			[$matricule],false
		);
	}

	public function getCount()
	{
		$res = DB::customQuery("SELECT COUNT(idEtudiant) AS count FROM etudiant",[],false);
		return (int)$res->count;
	}
	public function getCountSearch($query)
	{
		$res = DB::customQuery("SELECT COUNT(etudiant.idEtudiant) AS count
			FROM etudiant
			LEFT JOIN etudiantPT ON etudiant.idEtudiant=etudiantPT.idEtudiant
			LEFT JOIN horaireCours AS hc1 ON hc1.idHoraireCours=etudiantPT.pref1
			LEFT JOIN horaireCours AS hc2 ON hc2.idHoraireCours=etudiantPT.pref2
			WHERE etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR etudiantPT.numeroPT LIKE ?
			ORDER BY numeroPT DESC",
			[$query,$query,$query],false
		);
		return (int)$res->count;
	}

	public function create($fields,$values)
	{
		DB::insert("etudiant")
			->parametters($fields)
			->execute($values);
	}
	
	public function update($fields,$values)
	{
		DB::update("etudiant")
			->parametters($fields)
			->where("idEtudiant","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("etudiant")
			->where("idEtudiant","=")
			->execute([$id]);
	}
	/**
	 * Recuperer la derniere entree
	 * 
	 * */
	public function getLast()
	{
		$res = DB::customQuery("SELECT MAX(idEtudiant) AS max FROM etudiant",[],false);
		return (int)$res->max;
	}

	public function getLastMatricule()
	{
		$res = DB::customQuery("SELECT MAX(matricule) AS max FROM etudiant",[],false);
		return (int)$res->max;
	}

}