<?php 

class ResultatExamenModel extends CI_Model{

	public function getAll()
	{
		return DB::customQuery("SELECT resultatExamen.*,
			term.nomTerm,exercice.anneeExercice,
			etudiant.nom,etudiant.prenom,
			classe.codeClasse,niv.codeNiveau,
			rt.codeNiveau AS readyToCodeNiveau,
			inscriptionCours.joursCours
			FROM resultatExamen
			INNER JOIN term ON term.idTerm=resultatExamen.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN etudiant ON etudiant.matricule=resultatExamen.matriculeEtudiant
			INNER JOIN niveau AS niv ON niv.idNiveau=resultatExamen.idNiveau
			INNER JOIN classe ON niv.idClasse=classe.idClasse
			INNER JOIN niveau AS rt ON rt.idNiveau=resultatExamen.readyTo
			INNER JOIN inscriptionCours ON inscriptionCours.matriculeEtudiant=resultatExamen.matriculeEtudiant
			ORDER BY exercice.anneeExercice DESC,classe.idClasse"
		);
	}
	public function getAllSearch($query)
	{
		return DB::customQuery("SELECT resultatExamen.*,
			term.nomTerm,exercice.anneeExercice,
			etudiant.nom,etudiant.prenom,
			classe.codeClasse,niv.codeNiveau,
			rt.codeNiveau AS readyToCodeNiveau,
			inscriptionCours.joursCours
			FROM resultatExamen
			INNER JOIN term ON term.idTerm=resultatExamen.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN etudiant ON etudiant.matricule=resultatExamen.matriculeEtudiant
			INNER JOIN niveau AS niv ON niv.idNiveau=resultatExamen.idNiveau
			INNER JOIN classe ON niv.idClasse=classe.idClasse
			INNER JOIN niveau AS rt ON rt.idNiveau=resultatExamen.readyTo
			INNER JOIN inscriptionCours ON inscriptionCours.matriculeEtudiant=resultatExamen.matriculeEtudiant
			WHERE exercice.anneeExercice LIKE ?
			OR term.nomTerm LIKE ?
			OR resultatExamen.matriculeEtudiant LIKE ?
			OR etudiant.nom LIKE ?
			OR etudiant.prenom LIKE ?
			OR classe.codeClasse LIKE ?
			OR niv.codeNiveau LIKE ?
			ORDER BY exercice.anneeExercice DESC,classe.idClasse",
			[$query,$query,$query,$query,$query,$query,$query]
		);
	}

	public function getOne($id)
	{
		return DB::customQuery("SELECT resultatExamen.*,
			term.nomTerm,exercice.anneeExercice,
			etudiant.nom,etudiant.prenom,
			classe.codeClasse,niv.codeNiveau,
			rt.codeNiveau AS readyToCodeNiveau,
			inscriptionCours.joursCours
			FROM resultatExamen
			INNER JOIN term ON term.idTerm=resultatExamen.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN etudiant ON etudiant.matricule=resultatExamen.matriculeEtudiant
			INNER JOIN niveau AS niv ON niv.idNiveau=resultatExamen.idNiveau
			INNER JOIN classe ON niv.idClasse=classe.idClasse
			INNER JOIN niveau AS rt ON rt.idNiveau=resultatExamen.readyTo
			INNER JOIN inscriptionCours ON inscriptionCours.matriculeEtudiant=resultatExamen.matriculeEtudiant
			WHERE idResultatExamen=?",
			[$id],false
		);
	}

	public function create($fields,$values)
	{
		DB::insert("resultatExamen")
			->parametters($fields)
			->execute($values);
	}

	public function update($fields,$values)
	{
		DB::update("resultatExamen")
			->parametters($fields)
			->where("idResultatExamen","=")
			->execute($values);
	}

	public function delete($id)
	{
		DB::delete("resultatExamen")
			->where("idResultatExamen","=")
			->execute([$id]);
	}

	public function getByTermAndMatricule($term,$matricule)
	{
		return DB::select("resultatExamen")
					->where("idTerm","=")
					->and("matriculeEtudiant","=")
					->fetchOne([$term,$matricule]);
	}

	/**
	 * 
	 * Recuperer la derniere resultat d'examen d'un etudiant
	 * 
	 * */
	public function getLastResultat($term,$matricule)
	{
		$tm = new TermModel();
		$currentTerm = $tm->getOne($term);
		
		$currentTermNum = (int)$currentTerm->numeroTerm;
		$currentExercice = (int)$currentTerm->anneeExercice;

		$prevTermNum = $currentTermNum - 1;
		$prevExercice = $currentExercice;
		if($prevTermNum === 0)
		{
			$prevTermNum = 4;
			$prevExercice -= 1;
		}

		$res = DB::customQuery("SELECT * FROM resultatExamen
			INNER JOIN term ON term.idTerm=resultatExamen.idTerm
			INNER JOIN exercice ON exercice.idExercice=term.idExercice
			INNER JOIN niveau ON niveau.idNiveau=resultatExamen.readyTo
			INNER JOIN etudiant ON etudiant.matricule=resultatExamen.matriculeEtudiant
			WHERE term.numeroTerm=?
			AND exercice.anneeExercice=?
			AND resultatExamen.matriculeEtudiant=?",
			[$prevTermNum,$prevExercice,$matricule],false
		);

		if(!$res) 
		{
			$res = DB::customQuery("SELECT * FROM resultatExamen
				INNER JOIN term ON term.idTerm=resultatExamen.idTerm
				INNER JOIN exercice ON exercice.idExercice=term.idExercice
				INNER JOIN niveau ON niveau.idNiveau=resultatExamen.readyTo
				INNER JOIN etudiant ON etudiant.matricule=resultatExamen.matriculeEtudiant
				AND resultatExamen.matriculeEtudiant=?
				ORDER BY exercice.idExercice DESC,term.numeroTerm DESC",
				[$matricule],false
			);
		}

		return $res;
	}




}